#region Copyright
//
// Copyright (C) 2010-2011 by Autodesk, Inc.
//
// Permission to use, copy, modify, and distribute this software in
// object code form for any purpose and without fee is hereby granted,
// provided that the above copyright notice appears in all copies and
// that both that copyright notice and the limited warranty and
// restricted rights notice below appear in all supporting
// documentation.
//
// AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS.
// AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
// MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK, INC.
// DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL BE
// UNINTERRUPTED OR ERROR FREE.
//
// Use, duplication, or disclosure by the U.S. Government is subject to
// restrictions set forth in FAR 52.227-19 (Commercial Computer
// Software - Restricted Rights) and DFAR 252.227-7013(c)(1)(ii)
// (Rights in Technical Data and Computer Software), as applicable.
//
// 
#endregion // Copyright

#region Imports
using System;
using System.Collections.Generic;
using System.IO;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using Autodesk.Revit.ApplicationServices;
using Autodesk.Revit.Attributes;
using Autodesk.Revit.UI;
using Autodesk.Revit.DB;
#endregion

namespace DevDay2010
{
  //
  //  sample ribbon tab 
  //
  [Transaction( TransactionMode.Automatic )]
  [Journaling( JournalingMode.NoCommandData )]
  public class Ribbon : IExternalApplication
  {
    // ExternalCommands assembly path
    static string _assembly = typeof( Ribbon ).Assembly.Location;

    // Button icons directory
    static string _image = Path.GetDirectoryName( _assembly ) + "\\Images";

    public Result OnStartup( UIControlledApplication application )
    {
      try
      {
        // create custom ribbon tab 
        CreateRibbonTab( application );

        return Result.Succeeded;
      }
      catch( Exception ex )
      {
        System.Windows.Forms.MessageBox.Show(
          ex.ToString(), "DevDay 2010 Ribbon" );
        return Result.Failed;
      }
    }

    public Result OnShutdown( UIControlledApplication application )
    {
      return Result.Succeeded;
    }

    //
    //  create a custom ribbon tab 
    // 
    private void CreateRibbonTab( UIControlledApplication application )
    {
      //  create a ribbon tab, and create a ribbon panel, which contains three stackable buttons and one single push button.

      //  custom ribbon tab name.   
      string tabName = "DevDay 2010";
      application.CreateRibbonTab( tabName );

      //  panel 
      string firstPanelName = "DevDay Demo";
      RibbonPanel panel = application.CreateRibbonPanel( tabName, firstPanelName );

      //  simple push buttons 

      //  (1)  Active View  
      // 
      PushButtonData pushButtonDataActiveView = new PushButtonData(
          "PushButtonActiveView", "Active View", _assembly, "DevDay2010.Cmd_ActiveView" );

      // add a button to the panel 
      PushButton pushButtonActiveView = panel.AddItem( pushButtonDataActiveView ) as PushButton;

      // add an icon 
      // make sure you references to WindowsBase and PresentationCore, and import System.Windows.Media.Imaging namespace. 
      pushButtonActiveView.LargeImage = new BitmapImage( 
        new Uri( _image + "\\Basics.ico" ) );

      // add a tooltip 
      pushButtonActiveView.ToolTip = "Active View";

      panel.AddSeparator();

      //  (2)  Geometry Filter  
      // 
      PushButtonData pushButtonDataGeometryFilter = new PushButtonData(
          "PushButtonGeometryFilter", "Geometry Filter", _assembly, "DevDay2010.Cmd_GeometryFilter" );
      
      // add a button to the panel 
      PushButton pushButtonGeometryFilter = panel.AddItem( pushButtonDataGeometryFilter ) as PushButton;
      
      // add an icon 
      // make sure you references to WindowsBase and PresentationCore, and import System.Windows.Media.Imaging namespace. 
      pushButtonGeometryFilter.LargeImage = new BitmapImage( 
        new Uri( _image + "\\Basics.ico" ) );

      // add a tooltip 
      pushButtonGeometryFilter.ToolTip = "Geometry filter";

      panel.AddSeparator();

      //  (3)  Geometry API and AVF
      // 
      PushButtonData pushButtonDataGeometry2 = new PushButtonData(
          "PushButtonGeometry2", "Geometry\nAPI and AVF", _assembly, "DevDay2010.Cmd_GeometryApiAvf" );
      
      // add a button to the panel 
      PushButton pushButtonGeometry2 = panel.AddItem( pushButtonDataGeometry2 ) as PushButton;
      
      // add an icon 
      // make sure you references to WindowsBase and PresentationCore, and import System.Windows.Media.Imaging namespace. 
      pushButtonGeometry2.LargeImage = new BitmapImage( new Uri( _image + "\\Basics.ico" ) );
      
      // add a tooltip 
      pushButtonGeometry2.ToolTip = "Geometry API and AVF";

      panel.AddSeparator();
    }
  }
}
